@@ -23,5 +23,17 @@ if(interactive()) {
       svalue(b2) <- "open"
   })
 
+
+  ## handlers can be blocked/unblocked
+  b5 <- gbutton("Click me for a message", cont=g)
+  id <- addHandlerClicked(b5, function(h,...) print("Ouch"))
+  b6 <- gcheckbox("toggle handler message", cont=g, use.togglebutton=TRUE, handler=function(h,...) {
+      if (svalue(b6)) {
+          blockHandler(b5, id)
+      } else {
+          unblockHandler(b5, id)
+      }
+  })
+  
   visible(w) <- TRUE
 }
